@@ -12,7 +12,9 @@
 
 
 class Etcd3Exception(Exception):
-    pass
+    def __init__(self, detail_text=None, *args):
+        super(Etcd3Exception, self).__init__(*args)
+        self.detail_text = detail_text
 
 
 class WatchTimedOut(Etcd3Exception):
